@@ -17,23 +17,12 @@
  * with wavemon; see the file COPYING.  If not, write to the Free Software 
  * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
-
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <ncurses.h>
-
-#include "conf.h"
-#include "ui.h"
-#include "about_scr.h"
-#include "defs.h"
-
-struct wavemon_conf *conf;
+#include "wavemon.h"
 
 #define A_LINES 11
 
-char *about_lines[A_LINES] = { "wavemon - status monitor for wireless network devices",
-						WAVEMON_VERSION_STR,
+static char *about_lines[A_LINES] = { "wavemon - status monitor for wireless network devices",
+						"version " WAVEMON_VERSION " (" WAVEMON_RELEASE_DATE ") ",
 						"programmed by jan morgenstern <jan@jm-music.de>",
 						"distributed under the terms of GNU general public license >=v2",
 						"",
@@ -44,9 +33,10 @@ char *about_lines[A_LINES] = { "wavemon - status monitor for wireless network de
 						"",
 						"please contact me of you have any bug reports or suggestions!" };
 
-int *linecd[A_LINES];
+static int *linecd[A_LINES];
 
-void init_scramble() {
+static void init_scramble()
+{
 	int 	i, j;
 	
 	for (i = 0; i < A_LINES; i++) {
@@ -56,13 +46,15 @@ void init_scramble() {
 	}
 }
 
-void free_scramble() {
+static void free_scramble()
+{
 	int 	i;
 	
 	for (i = 0; i < A_LINES; i++) free(linecd[i]);
 }
 
-void draw_lines(WINDOW *w_about) {
+static void draw_lines(WINDOW *w_about)
+{
 	int		i, j;
 	char	buf[0x100];
 	
@@ -80,12 +72,11 @@ void draw_lines(WINDOW *w_about) {
 	}
 }	
 
-int scr_about(struct wavemon_conf *wmconf) {
+int scr_about()
+{
 	WINDOW	*w_about, *w_menu;
-	int		key = 0;
+	int	key = 0;
 	
-	conf = wmconf;
-
 	w_about = newwin_title(LINES - 1, COLS, 0, 0, "About", 0, 0);
 	w_menu = newwin(1, COLS, LINES - 1, 0);
 	
@@ -94,7 +85,7 @@ int scr_about(struct wavemon_conf *wmconf) {
 
 	init_scramble();
 	
-	do {
+	while (key < KEY_F(1) || key > KEY_F(10)) {
 		do {
 			draw_lines(w_about);
 			wrefresh(w_about);
@@ -103,12 +94,18 @@ int scr_about(struct wavemon_conf *wmconf) {
 			key = wgetch(w_menu);
 			usleep(5000); 
 		} while (key <= 0);
-	} while (key < 265 || key > 275);
+
+		/* Keyboard shortcuts */
+		if (key == 'q')
+			key = KEY_F(10);
+		else if (key == 'i')
+			key = KEY_F(1);
+	}
 	
 	free_scramble();
 	
 	werase(w_about); wrefresh(w_about); delwin(w_about);
 	werase(w_menu); wrefresh(w_menu); delwin(w_menu);
 	
-	return key - 265;
+	return key - KEY_F(1);
 }
