@@ -1,7 +1,7 @@
 /*
  * wavemon - a wireless network monitoring aplication
  *
- * Copyright (c) 2001 Jan Morgenstern <jan@jm-music.de>
+ * Copyright (c) 2001-2002 Jan Morgenstern <jan@jm-music.de>
  *
  * wavemon is free software; you can redistribute it and/or modify it under 
  * the terms of the GNU General Public License as published by the Free 
@@ -17,11 +17,8 @@
  * with wavemon; see the file COPYING.  If not, write to the Free Software 
  * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
-
-#include <stdio.h>
+#include "wavemon.h"
 #include <stdarg.h>
-#include <ncurses.h>
-#include "conf.h"
 
 void fatal_error(char *format, ...)
 {
@@ -29,9 +26,11 @@ void fatal_error(char *format, ...)
 	
 	endwin();
 	fprintf(stderr, "fatal error: ");
+
 	va_start(argp, format);
 	vfprintf(stderr, format, argp);
 	va_end(argp);
+
 	fprintf(stderr, "\n");
 	dealloc_on_exit();
 	exit(-1);
