@@ -17,97 +17,64 @@
  * with wavemon; see the file COPYING.  If not, write to the Free Software 
  * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
-
-#include <stdlib.h>
-#include <unistd.h>
-#include <ncurses.h>
-
-#include "conf.h"
-#include "ui.h"
-#include "timer.h"
 #include "iw_if.h"
-#include "net_if.h"
-#include "info_scr.h"
-#include "defs.h"
-
-struct wavemon_conf *conf;
 
 WINDOW	*w_if, *w_levels, *w_stats, *w_info, *w_net, *w_menu;
 
+/* GLOBALS */
 struct iw_range range;
+void (*iw_stat_redraw)(void);
 
-char *opmodes[] = { "auto", "ad-hoc", "managed", "master", "repeater", "secondary" };
-
-signed int random_level1(int min, int max)
+static void display_stats(char *ifname, WINDOW *w_levels, WINDOW *w_stats)
 {
-	static signed int rlvl, rlvl_next;
-	int i;
-
-	for (i = 0; i < 1; i++)
-		if (rlvl < rlvl_next) rlvl++;
-		else if (rlvl > rlvl_next) rlvl--;
-		else if (rlvl == rlvl_next)
-			rlvl_next = (rand() / (float)RAND_MAX) * (max - min) + min;
-	return rlvl;
-}
-
-int random_level2(int min, int max)
-{
-	static signed int rlvl, rlvl_next;
-	int i;
-
-	for (i = 0; i < 1; i++)
-		if (rlvl < rlvl_next) rlvl++;
-		else if (rlvl > rlvl_next) rlvl--;
-		else if (rlvl == rlvl_next)
-			rlvl_next = (rand() / (float)RAND_MAX) * (max - min) + min;
-	return rlvl;
-}
-
-void display_stats(char *ifname, WINDOW *w_levels, WINDOW *w_stats)
-{
-	int snr;
-	char nscale[2], lvlscale[2];
-	char snrscale[2] = { 6, 12 };
 	struct if_stat nstat;
+	char   nscale[2],
+	     lvlscale[2],
+	     snrscale[2] = { 6, 12 };
 	char tmp[0x100];
+	int snr;
 	
-	if (conf->linear) { lvlscale[0] = 10; lvlscale[1] = 50; }
-		else { lvlscale[0] = -40; lvlscale[1] = -20; };
+	if (conf.linear) {
+		lvlscale[0] = 10;
+		lvlscale[1] = 50;
+	} else {
+		lvlscale[0] = -40;
+		lvlscale[1] = -20;
+	}
 
-/*	iw_getstat(ifname, &stat, &stack, 256, conf->random); */
 	if_getstat(ifname, &nstat);
 	wmove(w_levels, 1, 1);
 	waddstr(w_levels, "link quality: ");
 	sprintf(tmp, "%d/%d  ", iw_stats.link, range.max_qual.qual);
 	waddstr_b(w_levels, tmp);
-	waddbar(w_levels, iw_stats.link, 0, range.max_qual.qual, 2, 1, COLS - 1, lvlscale, 1);
+	waddbar(w_levels, iw_stats.link, 0, range.max_qual.qual, 2, 1, COLS - 1, lvlscale, true);
 
 	wmove(w_levels, 3, 1);
 	waddstr(w_levels, "signal level: ");
-	sprintf(tmp, "%d dBm (%.2f uW)  ", iw_stats.signal, dbm2mw(iw_stats.signal) * 1000);
+	sprintf(tmp, "%d dBm (%s)", iw_stats.signal, dbm2units(iw_stats.signal));
 	waddstr_b(w_levels, tmp);
-	if (conf->linear) {
-		waddbar(w_levels, dbm2mw(iw_stats.signal), dbm2mw(conf->sig_min), 
-			dbm2mw(conf->sig_max), 4, 1, COLS - 1, lvlscale, 1);
-		if (conf->lthreshold_action)
-			waddthreshold(w_levels, dbm2mw(iw_stats.signal), dbm2mw(conf->lthreshold), 
-				dbm2mw(conf->sig_min), dbm2mw(conf->sig_max), 4, 1, COLS - 1, lvlscale, 1, '>');
-		if (conf->hthreshold_action)
-			waddthreshold(w_levels, dbm2mw(iw_stats.signal), dbm2mw(conf->hthreshold), 
-				dbm2mw(conf->sig_min), dbm2mw(conf->sig_max), 4, 1, COLS - 1, lvlscale, 1, '<');
+
+	if (conf.linear) {
+		waddbar(w_levels, dbm2mw(iw_stats.signal), dbm2mw(conf.sig_min),
+			dbm2mw(conf.sig_max), 4, 1, COLS - 1, lvlscale, true);
+		if (conf.lthreshold_action)
+			waddthreshold(w_levels, dbm2mw(iw_stats.signal), dbm2mw(conf.lthreshold),
+				dbm2mw(conf.sig_min), dbm2mw(conf.sig_max), 4, 1, COLS - 1, lvlscale, '>');
+		if (conf.hthreshold_action)
+			waddthreshold(w_levels, dbm2mw(iw_stats.signal), dbm2mw(conf.hthreshold),
+				dbm2mw(conf.sig_min), dbm2mw(conf.sig_max), 4, 1, COLS - 1, lvlscale, '<');
 	} else {
-		waddbar(w_levels, iw_stats.signal, conf->sig_min, conf->sig_max, 4, 1, COLS - 1, lvlscale, 1);
-		if (conf->lthreshold_action)
-			waddthreshold(w_levels, iw_stats.signal, conf->lthreshold, conf->sig_min, conf->sig_max, 4, 1,
-				COLS - 1, lvlscale, 1, '>');
-		if (conf->hthreshold_action)
-			waddthreshold(w_levels, iw_stats.signal, conf->hthreshold, conf->sig_min, conf->sig_max, 4, 1,
-				COLS - 1, lvlscale, 1, '<');
+		waddbar(w_levels, iw_stats.signal, conf.sig_min, conf.sig_max, 4, 1, COLS - 1, lvlscale, true);
+		if (conf.lthreshold_action)
+			waddthreshold(w_levels, iw_stats.signal, conf.lthreshold, conf.sig_min, conf.sig_max, 4, 1,
+				COLS - 1, lvlscale, '>');
+		if (conf.hthreshold_action)
+			waddthreshold(w_levels, iw_stats.signal, conf.hthreshold, conf.sig_min, conf.sig_max, 4, 1,
+				COLS - 1, lvlscale, '<');
 	}
 
 
-	if (conf->linear) {
+	if (conf.linear) {
 		nscale[0] = dbm2mw(iw_stats.signal) - 10;
 		nscale[1] = dbm2mw(iw_stats.signal);
 	} else {
@@ -116,29 +83,31 @@ void display_stats(char *ifname, WINDOW *w_levels, WINDOW *w_stats)
 	}
 	wmove(w_levels, 5, 1);
 	waddstr(w_levels, "noise level: ");
-	sprintf(tmp, "%d dBm (%.2f uW)  ", iw_stats.noise, dbm2mw(iw_stats.noise) * 1000);
+	sprintf(tmp, "%4d dBm (%s)", iw_stats.noise, dbm2units(iw_stats.noise));
 	waddstr_b(w_levels, tmp);
-	if (conf->linear)
-		waddbar(w_levels, dbm2mw(iw_stats.noise), dbm2mw(conf->noise_min),
-			dbm2mw(conf->noise_max), 6, 1, COLS - 1, nscale, 0);
-		else waddbar(w_levels, iw_stats.noise, conf->noise_min, conf->noise_max, 6, 1, COLS - 1, nscale, 0);
+	if (conf.linear)
+		waddbar(w_levels, dbm2mw(iw_stats.noise), dbm2mw(conf.noise_min),
+			dbm2mw(conf.noise_max), 6, 1, COLS - 1, nscale, false);
+	else
+		waddbar(w_levels, iw_stats.noise, conf.noise_min, conf.noise_max, 6, 1, COLS - 1, nscale, false);
 	
 	snr = iw_stats.signal - iw_stats.noise;
 	wmove(w_levels, 7, 1);
 	waddstr(w_levels, "signal-to-noise ratio: ");
-	if (snr > 0) waddstr_b(w_levels, "+");
+	if (snr > 0)
+		waddstr_b(w_levels, "+");
 	sprintf(tmp, "%d dB   ", snr);	
 	waddstr_b(w_levels, tmp);
-	waddbar(w_levels, snr, 0, 110, 8, 1, COLS - 1, snrscale, 1);
+	waddbar(w_levels, snr, 0, 110, 8, 1, COLS - 1, snrscale, true);
 	
 	wmove(w_stats, 1, 1);
 	
 	waddstr(w_stats, "RX: ");
-	sprintf(tmp, "%llu (%llu)", nstat.rx_packets, nstat.rx_bytes);
+	sprintf(tmp, "%llu (%s)", nstat.rx_packets, byte_units(nstat.rx_bytes));
 	waddstr_b(w_stats, tmp);
 	
 	waddstr(w_stats, ",  TX: ");
-	sprintf(tmp, "%llu (%llu)", nstat.tx_packets, nstat.tx_bytes);
+	sprintf(tmp, "%llu (%s)", nstat.tx_packets, byte_units(nstat.tx_bytes));
 	waddstr_b(w_stats, tmp);
 	
 	waddstr(w_stats, ",  inv: ");
@@ -153,16 +122,16 @@ void display_stats(char *ifname, WINDOW *w_levels, WINDOW *w_stats)
 	waddstr(w_stats, " misc");
 }
 
-void redraw_stats()
+static void redraw_stats()
 {
-	display_stats(conf->ifname, w_levels, w_stats);
+	display_stats(conf.ifname, w_levels, w_stats);
 	wrefresh(w_levels);
 	wrefresh(w_stats);
 	wmove(w_menu, 1, 0);
 	wrefresh(w_menu);
 }
 
-void display_info(char *ifname, WINDOW *w_if, WINDOW *w_info)
+static void display_info(char *ifname, WINDOW *w_if, WINDOW *w_info)
 {
 	struct iw_dyn_info info;
 	char 	tmp[0x100];
@@ -215,21 +184,15 @@ void display_info(char *ifname, WINDOW *w_if, WINDOW *w_info)
 	
 	wmove(w_info, 2, 1);
 	waddstr(w_info, "mode: ");
-	if (info.cap_mode) waddstr_b(w_info, opmodes[info.mode]);
+	if (info.cap_mode)
+		waddstr_b(w_info, iw_opmode(info.mode));
 	else waddstr(w_info, "n/a");
 
 	if (info.mode != 1) {
 		waddstr(w_info, ",  access point: ");
-		if (info.cap_ap) {
-			sprintf(tmp, "%02hhX:%02hhX:%02hhX:%02hhX:%02hhX:%02hhX", 
-				info.ap_addr.sa_data[0] & 0xFF,
-				info.ap_addr.sa_data[1] & 0xFF,
-				info.ap_addr.sa_data[2] & 0xFF,
-				info.ap_addr.sa_data[3] & 0xFF, 
-				info.ap_addr.sa_data[4] & 0xFF,
-				info.ap_addr.sa_data[5] & 0xFF);
-			waddstr_b(w_info, tmp);
-		} else waddstr(w_info, "n/a");
+		if (info.cap_ap)
+			waddstr_b(w_info, mac_addr((unsigned char *)info.ap_addr.sa_data));
+		else waddstr(w_info, "n/a");
 	}
 	
 	wmove(w_info, 3, 1);
@@ -300,12 +263,11 @@ void display_info(char *ifname, WINDOW *w_if, WINDOW *w_info)
 	} else waddstr(w_info, "n/a");
 }
 
-void display_netinfo(char *ifname, WINDOW *w_net)
+static void display_netinfo(char *ifname, WINDOW *w_net)
 {
 	struct if_info info;
-	char 	tmp[0x100];
-	int		ysize, xsize;
-	int		i;
+	int	ysize, xsize;
+	int	i;
 	
 	getmaxyx(w_net, ysize, xsize);
 	for (i = 1; i < ysize - 1; i++)
@@ -319,38 +281,25 @@ void display_netinfo(char *ifname, WINDOW *w_net)
 	waddstr_b(w_net, ifname);
 
 	waddstr(w_net, ",  hwaddr: ");
-	sprintf(tmp, "%02hhX:%02hhX:%02hhX:%02hhX:%02hhX:%02hhX",
-		info.hwaddr[0] & 0xFF, info.hwaddr[1] & 0xFF,
-		info.hwaddr[2] & 0xFF, info.hwaddr[3] & 0xFF,
-		info.hwaddr[4] & 0xFF, info.hwaddr[5] & 0xFF);
-	waddstr_b(w_net, tmp);
+	waddstr_b(w_net, mac_addr(info.hwaddr));
 
 	wmove(w_net, 2, 1);
 
 	waddstr(w_net, "addr: ");
-	sprintf(tmp, "%hhu.%hhu.%hhu.%hhu", info.addr[0] & 0xFF,
-		info.addr[1] & 0xFF, info.addr[2] & 0xFF, info.addr[3] & 0xFF);
-	waddstr_b(w_net, tmp);
+	waddstr_b(w_net, inet_ntoa(info.addr));
 
 	waddstr(w_net, ",  netmask: ");
-	sprintf(tmp, "%hhu.%hhu.%hhu.%hhu", info.netmask[0] & 0xFF,
-		info.netmask[1] & 0xFF, info.netmask[2] & 0xFF,
-		info.netmask[3] & 0xFF);
-	waddstr_b(w_net, tmp);
+	waddstr_b(w_net, inet_ntoa(info.netmask));
 
 	waddstr(w_net, ",  bcast: ");
-	sprintf(tmp, "%hhu.%hhu.%hhu.%hhu", info.bcast[0] & 0xFF,
-		info.bcast[1] & 0xFF, info.bcast[2] & 0xFF,
-		info.bcast[3] & 0xFF);
-	waddstr_b(w_net, tmp);
+	waddstr_b(w_net, inet_ntoa(info.bcast));
 }
 
-int scr_info(struct wavemon_conf *wmconf) {
-	struct timer t1;
-	int		key = 0;			/* burn, you devilish gnu compiler */
+int scr_info()
+{
+	struct timer	t1;
+	int		key = 0;
 	
-	conf = wmconf;
-
 	w_if = newwin_title(2, COLS, 0, 0, "Interface", 0, 1);
 	w_levels = newwin_title(9, COLS, 2, 0, "Levels", 1, 1);
 	w_stats = newwin_title(2, COLS, 11, 0, "Statistics", 1, 1);
@@ -358,10 +307,10 @@ int scr_info(struct wavemon_conf *wmconf) {
 	w_net = newwin_title(4, COLS, 19, 0, "Network", 1, 0);
 	w_menu = newwin(1, COLS, LINES - 1, 0);
 	
-	display_info(conf->ifname, w_if, w_info);
+	display_info(conf.ifname, w_if, w_info);
 	wrefresh(w_if);
 	wrefresh(w_info);
-	display_netinfo(conf->ifname, w_net);
+	display_netinfo(conf.ifname, w_net);
 	wrefresh(w_net);
 	wmenubar(w_menu, 0);
 	wrefresh(w_menu);
@@ -370,17 +319,24 @@ int scr_info(struct wavemon_conf *wmconf) {
 	
 	iw_stat_redraw = redraw_stats;
 
-	iw_getinf_range(conf->ifname, &range);
+	iw_getinf_range(conf.ifname, &range);
 
-	do {
-		display_info(conf->ifname, w_if, w_info);
-		display_netinfo(conf->ifname, w_net);
+	while (key < KEY_F(1) || key > KEY_F(10)) {
+		display_info(conf.ifname, w_if, w_info);
+		display_netinfo(conf.ifname, w_net);
 		wrefresh(w_if);
 		wrefresh(w_info);
 		wrefresh(w_net);
-		start_timer(&t1, conf->info_iv * 1000000);
-		while (!end_timer(&t1) && (key = wgetch(w_menu)) <= 0) sleep(1);
-	} while (key < 265 || key > 275);
+		start_timer(&t1, conf.info_iv * 1000000);
+		while (!end_timer(&t1) && (key = wgetch(w_menu)) <= 0)
+			sleep(1);
+
+		/* Keyboard shortcuts */
+		if (key == 'q')
+			key = KEY_F(10);
+		else if (key == 'i')
+			key = KEY_F(1);
+	}
 
 	iw_stat_redraw = NULL;
 	
@@ -391,5 +347,5 @@ int scr_info(struct wavemon_conf *wmconf) {
 	werase(w_net); wrefresh(w_net); delwin(w_net);
 	werase(w_menu); wrefresh(w_menu); delwin(w_menu);
 	
-	return key - 265;
+	return key - KEY_F(1);
 }
