@@ -17,14 +17,27 @@
  * with wavemon; see the file COPYING.  If not, write to the Free Software 
  * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
-
+#include "wavemon.h"
 #include <netdb.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+#include <linux/if.h>
 #include <linux/wireless.h>
 
 #define IW_STACKSIZE 1024
 
-struct iw_dyn_info {			// modified iwreq
-	char	cap_essid	: 1,	// capability flags
+/* Static network interface information - see netdevice(7) */
+struct if_info {			/* modified ifreq */
+	unsigned char	hwaddr[6];
+	struct in_addr	addr,
+			netmask,
+			bcast;
+};
+extern void if_getinf(char *ifname, struct if_info *info);
+
+struct iw_dyn_info {			/* modified iwreq */
+	char	cap_essid	: 1,
 			cap_nwid	: 1,
 			cap_nickname : 1,
 			cap_freq	: 1,
@@ -82,16 +95,6 @@ struct iw_dyn_info {			// modified iwreq
 	struct sockaddr ap_addr;
 };
 
-struct iw_aplist {
-	unsigned short num;
-	char	has_quality : 1;
-
-	struct {
-	  struct sockaddr   addr;
-	  struct iw_quality quality;
-	} aplist[IW_MAX_AP];
-};
-
 struct iw_stat {
 	int		link;
 	int		signal, noise;
@@ -100,15 +103,62 @@ struct iw_stat {
 
 extern struct iw_stat iw_stats;
 extern struct iw_stat iw_stats_cache[IW_STACKSIZE];
-void (*iw_stat_redraw)(void);
 
-int iw_check_extensions(char *ifname);
-void iw_getinf_dyn(char *ifname, struct iw_dyn_info *info);
-void iw_getinf_range(char *ifname, struct iw_range *range);
-int iw_getstat(char *ifname, struct iw_stat *stat, struct iw_stat *stack, int slotsize, char random);
-int iw_get_aplist(char *ifname, struct iw_aplist *lst);
-void init_stat_iv(struct wavemon_conf *conf);
-int iw_getif();
-float dbm2mw(float in);
-float mw2dbm(float in);
-float freq2ghz(struct iw_freq *f);
+struct if_stat {
+	unsigned long long rx_packets, tx_packets;
+	unsigned long long rx_bytes, tx_bytes;
+};
+
+extern void if_getstat(char *ifname, struct if_stat *stat);
+extern void iw_getinf_dyn(char *ifname, struct iw_dyn_info *info);
+extern void iw_getinf_range(char *ifname, struct iw_range *range);
+
+extern void (*iw_stat_redraw)(void);
+
+static inline const char *iw_opmode(const uint8_t mode)
+{
+	static char *modes[] = {"Auto",
+				"Ad-Hoc",
+				"Managed",
+				"Master",
+				"Repeater",
+				"Secondary",
+				"Monitor"
+	};
+	return mode > 6 ? "Unknown/bug" : modes[mode];
+}
+
+/* Convert log dBm values to linear mW */
+static inline double dbm2mw(const double in)
+{
+	return pow(10.0, in / 10.0);
+}
+
+static inline char *dbm2units(const double in)
+{
+	static char with_units[0x100];
+	double val = dbm2mw(in);
+
+	if (val < 0.00000001) {
+		sprintf(with_units, "%.2f pW", val * 1e9);
+	} else if (val < 0.00001) {
+		sprintf(with_units, "%.2f nW", val * 1e6);
+	} else if (val < 0.01) {
+		sprintf(with_units, "%.2f uW", val * 1e3);
+	} else {
+		sprintf(with_units, "%.2f mW", val);
+	}
+	return with_units;
+}
+
+/* Convert linear mW values to log dBm */
+static inline double mw2dbm(const double in)
+{
+	return pow(10.0, in / 10.0);
+}
+
+/* Convert frequency to GHz */
+static inline float freq2ghz(const struct iw_freq *f)
+{
+	return (f->e ? f->m * pow(10, f->e) : f->m) / 1e9;
+}
