@@ -17,18 +17,14 @@
  * with wavemon; see the file COPYING.  If not, write to the Free Software 
  * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+#define LISTVAL_MAX	32	/* maximum string length of `s' elements */
 
 int 	ll_create();
 void 	*ll_get(int ld, unsigned long n);
 void 	*ll_getall(int ld);
 void 	ll_reset(int ld);
 void 	ll_push(int ld, const char *format, ...);
-void 	*ll_pop(int ld);
-void 	ll_unshift(int ld, const char *format, ...);
-void 	*ll_shift(int ld);
 void 	ll_replace(int ld, unsigned long n, const char *format, ...);
-void 	ll_del(int ld, unsigned long n);
-char 	ll_type(int ld, unsigned long n);
 signed long ll_scan(int ld, const char *format, ...);
 unsigned long ll_size(int ld);
 void 	ll_destroy(int ld);
